@@ -1,4 +1,7 @@
-"""Tools for metamodern software packaging."""
+"""
+Tools for metamodern software packaging.
+
+"""
 
 from pkg_resources import DistributionNotFound
 from pkg_resources import iter_entry_points as get_entry_points
