@@ -49,7 +49,13 @@ class Publish:
         version = str(sh.poetry("version", "-s")).strip()
         asset = str(sh.tail(sh.grep(sh.ls("-tr", "dist"), ".whl"),
                     "-n1")).strip()
-        print(sh.gh("release", "create", version, f"dist/{asset}"))
+        previous_version = str(sh.git("describe", "--tags",
+                                      "--abbrev=0")).strip()
+        changelog = sh.git("--no-pager", "log", "--no-color",
+                           f"{previous_version}..HEAD^", "--oneline",
+                           "--no-decorate")
+        print(sh.gh("release", "create", version, f"dist/{asset}",
+                    "--notes", changelog))
         print(sh.git("pull"))
         print(f"Published release {version}!")
         return 0
